==> ui-18.0.3.tgz: package/components/time-picker/Panel.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { freeze } from 'immer';
import { isUndefined } from 'lodash';
import React, { useImperativeHandle, useRef, useState } from 'react';
import { useEventCallback } from '@react-devui/hooks';
import { getClassName, scrollTo } from '@react-devui/utils';
import { dayjs } from '../../dayjs';
import { usePrefixConfig } from '../root';
const H12 = freeze(['12', ...Array.from({ length: 11 }).map((_, i) => `${i + 1 < 10 ? '0' : ''}${i + 1}`)]);
const [H24, M60, S60] = [24, 60, 60].map((num) => freeze(Array.from({ length: num }).map((_, i) => `${i < 10 ? '0' : ''}${i}`)));
function Panel(props, ref) {
    const { dTime, dCols, d12Hour, dConfigTime, onTimeChange, __header = false } = props;
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const ulHRef = useRef(null);
    const ulMRef = useRef(null);
    const ulSRef = useRef(null);
    //#endregion
    const dataRef = useRef({});
    const [saveA, setSaveA] = useState('AM');
    const activeTime = dTime ? dayjs(dTime) : dayjs('00:00:00', 'HH:mm:ss');
    const activeA = dTime ? (activeTime.get('hour') < 12 ? 'AM' : 'PM') : saveA;
    const format = (() => {
        const unit = [];
        if (dCols.includes('hour')) {
            unit.push('HH');
        }
        if (dCols.includes('minute')) {
            unit.push('mm');
        }
        if (dCols.includes('second')) {
            unit.push('ss');
        }
        return unit.join(':');
    })();
    const updateView = useEventCallback((t, unit) => {
        var _a, _b, _c, _d, _e, _f;
        if (unit === 'hour' || isUndefined(unit)) {
            let hour = t.getHours();
            if (d12Hour) {
                if (activeA === 'AM' && hour > 11) {
                    hour -= 12;
                }
                if (activeA === 'PM' && hour < 12) {
                    hour += 12;
                }
            }
            if (ulHRef.current) {
                (_b = (_a = dataRef.current).clearHTid) === null || _b === void 0 ? void 0 : _b.call(_a);
                dataRef.current.clearHTid = scrollTo(ulHRef.current, {
                    top: Array.prototype.indexOf.call(ulHRef.current.children, ulHRef.current.querySelector(`[data-h="${hour}"]`)) * 28,
                    behavior: 'smooth',
                });
            }
        }
        if (unit === 'minute' || isUndefined(unit)) {
            const minute = t.getMinutes();
            if (ulMRef.current) {
                (_d = (_c = dataRef.current).clearMTid) === null || _d === void 0 ? void 0 : _d.call(_c);
                dataRef.current.clearMTid = scrollTo(ulMRef.current, {
                    top: Array.prototype.indexOf.call(ulMRef.current.children, ulMRef.current.querySelector(`[data-m="${minute}"]`)) * 28,
                    behavior: 'smooth',
                });
            }
        }
        if (unit === 'second' || isUndefined(unit)) {
            const second = t.getSeconds();
            if (ulSRef.current) {
                (_f = (_e = dataRef.current).clearSTid) === null || _f === void 0 ? void 0 : _f.call(_e);
                dataRef.current.clearSTid = scrollTo(ulSRef.current, {
                    top: Array.prototype.indexOf.call(ulSRef.current.children, ulSRef.current.querySelector(`[data-s="${second}"]`)) * 28,
                    behavior: 'smooth',
                });
            }
        }
    });
    useImperativeHandle(ref, () => updateView, [updateView]);
    return (_jsxs("div", Object.assign({ className: `${dPrefix}time-picker__panel` }, { children: [__header && _jsx("div", Object.assign({ className: `${dPrefix}time-picker__header` }, { children: activeTime.format(format) })), dCols.includes('hour') && (_jsx("ul", Object.assign({ ref: ulHRef, className: `${dPrefix}time-picker__column` }, { children: (d12Hour ? H12 : H24).map((_h) => {
                    var _a;
                    let h = Number(_h);
                    if (d12Hour) {
                        if (activeA === 'AM' && h === 12) {
                            h = 0;
                        }
                        if (activeA === 'PM' && h !== 12) {
                            h += 12;
                        }
                    }
                    const { disabled, hidden } = (_a = dConfigTime === null || dConfigTime === void 0 ? void 0 : dConfigTime('hour', h)) !== null && _a !== void 0 ? _a : {};
                    return hidden ? null : (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                            'is-active': dTime && activeTime.get('hour') === h,
                            'is-disabled': disabled,
                        }), "data-h": h, onClick: () => {
                            const newT = activeTime.set('hour', h).toDate();
                            updateView(newT, 'hour');
                            onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                        } }, { children: _h }), h));
                }) }))), dCols.includes('minute') && (_jsx("ul", Object.assign({ ref: ulMRef, className: `${dPrefix}time-picker__column` }, { children: M60.map((_m) => {
                    var _a;
                    const m = Number(_m);
                    const { disabled, hidden } = (_a = dConfigTime === null || dConfigTime === void 0 ? void 0 : dConfigTime('minute', m)) !== null && _a !== void 0 ? _a : {};
                    return hidden ? null : (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                            'is-active': dTime && activeTime.get('minute') === m,
                            'is-disabled': disabled,
                        }), "data-m": m, onClick: () => {
                            const newT = activeTime.set('minute', m).toDate();
                            updateView(newT, 'minute');
                            onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                        } }, { children: _m }), m));
                }) }))), dCols.includes('second') && (_jsx("ul", Object.assign({ ref: ulSRef, className: `${dPrefix}time-picker__column` }, { children: S60.map((_s) => {
                    var _a;
                    const s = Number(_s);
                    const { disabled, hidden } = (_a = dConfigTime === null || dConfigTime === void 0 ? void 0 : dConfigTime('second', s)) !== null && _a !== void 0 ? _a : {};
                    return hidden ? null : (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                            'is-active': dTime && activeTime.get('second') === s,
                            'is-disabled': disabled,
                        }), "data-s": s, onClick: () => {
                            const newT = activeTime.set('second', s).toDate();
                            updateView(newT, 'second');
                            onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                        } }, { children: _s }), s));
                }) }))), d12Hour && (_jsx("ul", Object.assign({ className: `${dPrefix}time-picker__column` }, { children: ['AM', 'PM'].map((A) => (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                        'is-active': activeA === A,
                    }), onClick: () => {
                        if (dTime) {
                            if (activeA !== A) {
                                const newT = activeTime.set('hour', activeTime.get('hour') + (A === 'AM' ? -12 : 12)).toDate();
                                onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                            }
                        }
                        else {
                            setSaveA(A);
                        }
                    } }, { children: A }), A))) })))] })));
}
export const DPanel = React.forwardRef(Panel);

==> ui-18.1.4.tgz: package/components/time-picker/Panel.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { freeze } from 'immer';
import { isUndefined } from 'lodash';
import React, { useImperativeHandle, useRef, useState } from 'react';
import { useEventCallback } from '@react-devui/hooks';
import { getClassName, scrollTo } from '@react-devui/utils';
import dayjs from '../../dayjs';
import { usePrefixConfig } from '../root';
const H12 = freeze(['12', ...Array.from({ length: 11 }).map((_, i) => `${i + 1 < 10 ? '0' : ''}${i + 1}`)]);
const [H24, M60, S60] = [24, 60, 60].map((num) => freeze(Array.from({ length: num }).map((_, i) => `${i < 10 ? '0' : ''}${i}`)));
function Panel(props, ref) {
    const { dTime, dCols, d12Hour, dConfigTime, onTimeChange, __header = false } = props;
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const ulHRef = useRef(null);
    const ulMRef = useRef(null);
    const ulSRef = useRef(null);
    //#endregion
    const dataRef = useRef({});
    const [saveA, setSaveA] = useState('AM');
    const activeTime = dTime ? dayjs(dTime) : dayjs('00:00:00', 'HH:mm:ss');
    const activeA = dTime ? (activeTime.get('hour') < 12 ? 'AM' : 'PM') : saveA;
    const format = (() => {
        const unit = [];
        if (dCols.includes('hour')) {
            unit.push('HH');
        }
        if (dCols.includes('minute')) {
            unit.push('mm');
        }
        if (dCols.includes('second')) {
            unit.push('ss');
        }
        return unit.join(':');
    })();
    const updateView = useEventCallback((t, unit) => {
        var _a, _b, _c, _d, _e, _f;
        if (unit === 'hour' || isUndefined(unit)) {
            let hour = t.getHours();
            if (d12Hour) {
                if (activeA === 'AM' && hour > 11) {
                    hour -= 12;
                }
                if (activeA === 'PM' && hour < 12) {
                    hour += 12;
                }
            }
            if (ulHRef.current) {
                (_b = (_a = dataRef.current).clearHTid) === null || _b === void 0 ? void 0 : _b.call(_a);
                dataRef.current.clearHTid = scrollTo(ulHRef.current, {
                    top: Array.prototype.indexOf.call(ulHRef.current.children, ulHRef.current.querySelector(`[data-h="${hour}"]`)) * 28,
                    behavior: 'smooth',
                });
            }
        }
        if (unit === 'minute' || isUndefined(unit)) {
            const minute = t.getMinutes();
            if (ulMRef.current) {
                (_d = (_c = dataRef.current).clearMTid) === null || _d === void 0 ? void 0 : _d.call(_c);
                dataRef.current.clearMTid = scrollTo(ulMRef.current, {
                    top: Array.prototype.indexOf.call(ulMRef.current.children, ulMRef.current.querySelector(`[data-m="${minute}"]`)) * 28,
                    behavior: 'smooth',
                });
            }
        }
        if (unit === 'second' || isUndefined(unit)) {
            const second = t.getSeconds();
            if (ulSRef.current) {
                (_f = (_e = dataRef.current).clearSTid) === null || _f === void 0 ? void 0 : _f.call(_e);
                dataRef.current.clearSTid = scrollTo(ulSRef.current, {
                    top: Array.prototype.indexOf.call(ulSRef.current.children, ulSRef.current.querySelector(`[data-s="${second}"]`)) * 28,
                    behavior: 'smooth',
                });
            }
        }
    });
    useImperativeHandle(ref, () => updateView, [updateView]);
    return (_jsxs("div", Object.assign({ className: `${dPrefix}time-picker__panel` }, { children: [__header && _jsx("div", Object.assign({ className: `${dPrefix}time-picker__header` }, { children: activeTime.format(format) })), dCols.includes('hour') && (_jsx("ul", Object.assign({ ref: ulHRef, className: `${dPrefix}time-picker__column` }, { children: (d12Hour ? H12 : H24).map((_h) => {
                    var _a;
                    let h = Number(_h);
                    if (d12Hour) {
                        if (activeA === 'AM' && h === 12) {
                            h = 0;
                        }
                        if (activeA === 'PM' && h !== 12) {
                            h += 12;
                        }
                    }
                    const { disabled, hidden } = (_a = dConfigTime === null || dConfigTime === void 0 ? void 0 : dConfigTime('hour', h)) !== null && _a !== void 0 ? _a : {};
                    return hidden ? null : (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                            'is-active': dTime && activeTime.get('hour') === h,
                            'is-disabled': disabled,
                        }), "data-h": h, onClick: () => {
                            const newT = activeTime.set('hour', h).toDate();
                            updateView(newT, 'hour');
                            onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                        } }, { children: _h }), h));
                }) }))), dCols.includes('minute') && (_jsx("ul", Object.assign({ ref: ulMRef, className: `${dPrefix}time-picker__column` }, { children: M60.map((_m) => {
                    var _a;
                    const m = Number(_m);
                    const { disabled, hidden } = (_a = dConfigTime === null || dConfigTime === void 0 ? void 0 : dConfigTime('minute', m)) !== null && _a !== void 0 ? _a : {};
                    return hidden ? null : (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                            'is-active': dTime && activeTime.get('minute') === m,
                            'is-disabled': disabled,
                        }), "data-m": m, onClick: () => {
                            const newT = activeTime.set('minute', m).toDate();
                            updateView(newT, 'minute');
                            onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                        } }, { children: _m }), m));
                }) }))), dCols.includes('second') && (_jsx("ul", Object.assign({ ref: ulSRef, className: `${dPrefix}time-picker__column` }, { children: S60.map((_s) => {
                    var _a;
                    const s = Number(_s);
                    const { disabled, hidden } = (_a = dConfigTime === null || dConfigTime === void 0 ? void 0 : dConfigTime('second', s)) !== null && _a !== void 0 ? _a : {};
                    return hidden ? null : (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                            'is-active': dTime && activeTime.get('second') === s,
                            'is-disabled': disabled,
                        }), "data-s": s, onClick: () => {
                            const newT = activeTime.set('second', s).toDate();
                            updateView(newT, 'second');
                            onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                        } }, { children: _s }), s));
                }) }))), d12Hour && (_jsx("ul", Object.assign({ className: `${dPrefix}time-picker__column` }, { children: ['AM', 'PM'].map((A) => (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}time-picker__cell`, {
                        'is-active': activeA === A,
                    }), onClick: () => {
                        if (dTime) {
                            if (activeA !== A) {
                                const newT = activeTime.set('hour', activeTime.get('hour') + (A === 'AM' ? -12 : 12)).toDate();
                                onTimeChange === null || onTimeChange === void 0 ? void 0 : onTimeChange(newT);
                            }
                        }
                        else {
                            setSaveA(A);
                        }
                    } }, { children: A }), A))) })))] })));
}
export const DPanel = React.forwardRef(Panel);
